Skip to content

Return metadata for configured external CraftGRN demo data

Usage

craftgrn_demo_data_info(demo = NULL)

Arguments

demo

Optional demo bundle name. No external demo bundle is currently configured.

Value

A data frame with the bundle URL, checksum, archive file name, and extracted project directory name. When no demo bundle is configured, the returned data frame has zero rows.